OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage invalid" : "Некоректне сховище",
    "Unknown error" : "Невідома помилка",
    "File could not be found" : "Неможливо знайти файл",
    "Move or copy" : "Перемістити або копіювати",
    "Download" : "Звантажити",
    "Delete" : "Вилучити",
    "Tags" : "Мітки",
    "Show list view" : "Подання списком",
    "Show grid view" : "Подання сіткою",
    "Home" : "Домівка",
    "Close" : "Закрити",
    "Favorites" : "Із зірочкою",
    "Could not create folder \"{dir}\"" : "Неможливо створити каталог \"{dir}\"",
    "This will stop your current uploads." : "Ця дія призведе до зупинки поточних завантажень на сервер.",
    "Upload cancelled." : "Завантаження скасовано.",
    "Processing files …" : "Триває обробка файлів...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо завантажити {filename}, оскільки він є або каталогом, або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви завантажуєте {size1}, а залишилося лише {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Каталог призначення \"{dir}\" більше не дійсний.",
    "Not enough free space" : "Недостатньо вільного місця",
    "An unknown error has occurred" : "Сталася невідома помилка",
    "File could not be uploaded" : "Неможливо завантажити файл",
    "Uploading …" : "Завантаження…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Завантаження цього елемента не підтримується",
    "Target folder does not exist any more" : "Каталог призначення більше не дійсний",
    "Operation is blocked by access control" : "Операцію заблоковано через контроль доступу",
    "Error when assembling chunks, status code {status}" : "Помилка під час збірки частин, код помилки {status}",
    "Actions" : "Дії",
    "Rename" : "Перейменувати",
    "Move" : "Перемістити",
    "Copy" : "Копіювати",
    "Choose target folder" : "Виберіть каталог призначення",
    "Edit locally" : "Редагувати локально",
    "Open" : "Відкрити",
    "Delete file" : "Вилучити файл",
    "Delete folder" : "Вилучити каталог",
    "Disconnect storage" : "Від’єднати сховище",
    "Leave this share" : "Вийти зі спільного доступу",
    "Could not load info for file \"{file}\"" : "Не вдалося завантажити дані про файл \"{file}\"",
    "Files" : "Файли",
    "Details" : "Деталі",
    "Please select tag(s) to add to the selection" : "Виберіть позначки, які ви додасте до вибраного",
    "Apply tag(s) to selection" : "Застосувати позначки до вибраного",
    "Select directory \"{dirName}\"" : "Виберіть каталог \"{dirName}\"",
    "Select file \"{fileName}\"" : "Вибрати файл \"{fileName}\"",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "This operation is forbidden" : "Операцію заборонено",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "Could not move \"{file}\", target exists" : "Не вдається перемістити файл \"{file}\", оскільк він існує в точці призначення",
    "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
    "copy" : "копія",
    "Could not copy \"{file}\", target exists" : "Не вдається скопіювати файл \"{file}\", оскільки він вже присутній в точці призначення",
    "Could not copy \"{file}\"" : "Неможливо скопіювати \"{file}\"",
    "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} та {nbfiles} інших файлів скопійовано до {destination}",
    "{newName} already exists" : "{newName} вже існує",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неможливо перейменувати \"{fileName}\", оскільки такий файл більше не існує",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{targetName}\" вже використовується у каталозі \"{dir}\". Будь-ласка, виберіть іншу назву.",
    "Could not rename \"{fileName}\"" : "Неможливо перейменувати \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки він вже існує.",
    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки він вже існує.",
    "Could not fetch file details \"{file}\"" : "Неможливо отримати деталі файлу \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Помилка вилучення файлу \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Для пошуку в інших каталогах потрібно зазначити більше двох символів",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n ","файли: %n "],
    "{dirs} and {files}" : "{dirs} та {files}",
    "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включно %n прихованих"],
    "You do not have permission to upload or create files here" : "У вас відсутні повноваження для завантаження або створення файлів тут",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Завантаження %n файлів"],
    "New file/folder menu" : "Меню з новим файлом/каталогом",
    "Select file range" : "Вибрати кілька файлів",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "Використано {used} із {quota}",
    "{used} used" : "Використано {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" є некоректним ім'ям файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "\"/\" is not allowed inside a file name." : "Символ \"/\" не дозволено в імені файлу.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" є неприпустимим типом файлу",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Сховище {owner} переповнено, подальша синхронізація файлів неможлива!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Груповий каталог \"{mountPoint}\" переповнено, подальша синхронізація файлів неможлива!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Зовнішнє сховище \"{mountPoint}\" переповнено, подальша синхронізація файлів не можлива!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше сховище переповнено, подальша синхронізація файлів неможлива!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Сховище користувача {owner} майже заповнений ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Груповий каталог \"{mountPoint}\" майже заповнений ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Зовнішнє сховище \"{mountPoint}\" майже заповнено ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше сховище майже заповнено ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\""],
    "View in folder" : "Переглянути у каталозі",
    "Copied!" : "Скопійовано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Скопіювати пряме посилання (користувачі мають мати доступ до цього файлу чи каталогу)",
    "Path" : "Шлях",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт(ів)"],
    "Favorited" : "Вподобано",
    "Favorite" : "Вподобати",
    "You can only favorite a single file or folder at a time" : "Одночасно можна вподобати лише один файл або каталог",
    "New folder" : "Новий каталог",
    "Upload file" : "Завантажити файл",
    "Recent" : "Останні",
    "Not favorited" : "Без зірочки",
    "Remove from favorites" : "Прибрати із вподобаного",
    "Add to favorites" : "Вподобати",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "Added to favorites" : "Додано до вподобаного",
    "Removed from favorites" : "Вилучено із вподобаного",
    "You added {file} to your favorites" : "Ви вподобали {file}",
    "You removed {file} from your favorites" : "Ви вилучили {file} із вподобаного",
    "File changes" : "Зміни у файлах",
    "Created by {user}" : "Створено користувачем {user}",
    "Changed by {user}" : "Змінено користувачем {user}",
    "Deleted by {user}" : "Вилучено користувачем {user}",
    "Restored by {user}" : "Відновлено користувачем {user}",
    "Renamed by {user}" : "Перейменовано користувачем {user}",
    "Moved by {user}" : "Переміщено користувачем {user}",
    "\"remote user\"" : "\"віддалений користувач\"",
    "You created {file}" : "Ви створили {file}",
    "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
    "{user} created {file}" : "Користувач {user} створив {file}",
    "{user} created an encrypted file in {file}" : "{user} створив зашифрований файл у {file}",
    "{file} was created in a public folder" : "Файл {file} створено у публічному каталозі",
    "You changed {file}" : "Ви змінили файл {file}",
    "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
    "{user} changed {file}" : "Користувач {user} змінив файл {file}",
    "{user} changed an encrypted file in {file}" : "{user} змінив зашифрований файл у {file}",
    "You deleted {file}" : "Ви вилучили {file}",
    "You deleted an encrypted file in {file}" : "Ви вилучити зашифрований файл у {file}",
    "{user} deleted {file}" : "Користувач {user} вилучив {file}",
    "{user} deleted an encrypted file in {file}" : "{user} вилучив зашифрований файл у {file}",
    "You restored {file}" : "Ви відновили {file}",
    "{user} restored {file}" : "Користувач {user} відновив {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ви перейменували {oldfile} (прихований) у {newfile} (прихований)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Ви перейменували {oldfile} (прихований) у {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Ви перейменували {oldfile} у {newfile} (прихований)",
    "You renamed {oldfile} to {newfile}" : "Ви перейменували {oldfile} у {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} перейменував {oldfile} (прихований) у {newfile} (прихований)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} перейменував {oldfile} (прихований) у {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} перейменував {oldfile} у {newfile} (прихований)",
    "{user} renamed {oldfile} to {newfile}" : "Користувач {user} перейменував {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Користувач {user} перемістив {oldfile} до {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл було додано або вилучено з ваших <strong>вподобаних</strong> документів",
    "A file or folder has been <strong>changed</strong>" : "Файл або каталог було <strong> змінено </strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Вподобаний файли або каталог було <strong>змінено</strong>",
    "All files" : "Усі файли",
    "Unlimited" : "Необмежено",
    "Upload (max. %s)" : "Завантаження (макс. %s)",
    "Accept" : "Прийняти",
    "Reject" : "Відхилити",
    "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передачу прав власності",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Прийняти {path}?\n\nУвага: процес передачі після прийняття може тривати до 1 години.",
    "Ownership transfer failed" : "Не вдалося передати право власності",
    "Your ownership transfer of {path} to {user} failed." : "Передача вашого права власності на {path} користувачеві {user} не вдалася.",
    "The ownership transfer of {path} from {user} failed." : "Передача права на власність {path} від користувача {user} не вдалася.",
    "Ownership transfer done" : "Право власності передано",
    "Your ownership transfer of {path} to {user} has completed." : "Передачу вашого права на власність на {path} користувачеві {user} виконано.",
    "The ownership transfer of {path} from {user} has completed." : "Передачу права на власність на {path} від користувача {user} завершено.",
    "in %s" : "в %s",
    "File Management" : "Керування файлами",
    "Transfer ownership of a file or folder" : "Передача права на власність на файл або каталог",
    "Choose file or folder to transfer" : "Виберіть файл або каталог для передачі",
    "Change" : "Змінити",
    "New owner" : "Новий власник",
    "Search users" : "Пошук користувачів",
    "Choose a file or folder to transfer" : "Виберіть файл або каталог для передачі",
    "Transfer" : "Передати",
    "Transfer {path} to {userid}" : "Передати {path} користувачеві {userid}",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Ownership transfer request sent" : "Запит на передачу прав власності надіслано",
    "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
    "Unable to change the favourite state of the file" : "Неможливо змінити стан \"вподобано\" для цього файла",
    "Error while loading the file data" : "Помилка під час завантаження даних про файл",
    "Pick a template for {name}" : "Вибрати шаблон для {name}",
    "Cancel" : "Скасувати",
    "Create" : "Створити",
    "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
    "Creating file" : "Створення файлу",
    "Blank" : "Порожньо",
    "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
    "Set up templates folder" : "Встановити каталог з шаблонами",
    "Templates" : "Шаблони",
    "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
    "%s used" : "%s використано",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "Використано %1$s із %2$s",
    "Files settings" : "Налаштування файлів",
    "Show hidden files" : "Показувати приховані файли",
    "Crop image previews" : "Кадрування попереднього перегляду зображень",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
    "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s",
    "Toggle grid view" : "Перемкнути подання сіткою",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
    "No entries found in this folder" : "В цьому каталозі нічого немає",
    "Select all" : "Вибрати все",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
    "No favorites yet" : "Поки немає вподобаного",
    "Files and folders you mark as favorite will show up here" : "Файли та каталоги, які ви вподобали, з’являться тут",
    "Deleted files" : "Кошик",
    "Shares" : "Спільний доступ",
    "Shared with others" : "Ви поділилися",
    "Shared with you" : "Надано доступ вам",
    "Shared by link" : "Доступ за посиланням",
    "Deleted shares" : "Більше недоступні",
    "Pending shares" : "Запити на доступ",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл.txt",
    "Select" : "Вибрати",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для завантаження або створення файлів тут",
    "New" : "Створити",
    "Cannot transfer ownership of a file or folder you don't own" : "Неможливо передати права власності на файл або каталог, що вам не належить",
    "%s%% of %s used" : "%s%% із %s використано",
    "Settings" : "Налаштування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
